markuptools.remove_markup_attached_to_component
===============================================

.. autofunction:: abjad.tools.markuptools.remove_markup_attached_to_component.remove_markup_attached_to_component
